=====
brreg
=====

brreg is a Python client for `Brønnøysundregistrene <https://www.brreg.no/>`_'s
open API. Brønnøysundregistrene is the official registry for Norwegian
organizations and more.

brreg is available from PyPI. To install it, run::

    pip install brreg

For details and code examples, see `the brreg documentation
<https://brreg.readthedocs.io/>`_.


License
=======

Copyright 2019 `Otovo AS <https://www.otovo.com/>`_. Licensed under the Apache
License, Version 2.0. See the ``LICENSE`` file for the full license text.


Project resources
=================

- `Documentation <https://brreg.readthedocs.io/>`_
- `Source code <https://github.com/otovo/python-brreg>`_
- `Issue tracker <https://github.com/otovo/python-brreg/issues>`_

.. image:: https://img.shields.io/pypi/v/brreg.svg?style=flat
    :target: https://pypi.org/project/brreg/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/travis/otovo/python-brreg/master.svg?style=flat
    :target: https://travis-ci.com/otovo/python-brreg
    :alt: Travis CI build status

.. image:: https://img.shields.io/coveralls/otovo/python-brreg/master.svg?style=flat
    :target: https://coveralls.io/github/otovo/python-brreg
    :alt: Test coverage
